==> tgp_1.1-3.tar.gz: tgp/R/tgp.cleanup.R <==
#******************************************************************************* 
#
# Bayesian Regression and Adaptive Sampling with Gaussian Process Trees
# Copyright (C) 2005, University of California
# 
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# 
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
# 
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
#
# Questions? Contact Robert B. Gramacy (rbgramacy@ams.ucsc.edu)
#
#*******************************************************************************


"tgp.cleanup" <-
  function()
{
  .C("tgp_cleanup", PACKAGE = "tgp")
  
  ## gather information about partitions
  if(file.exists(paste("./", "parts_1.out", sep=""))) {
    cat("INTERRUPT: removed parts_1.out\n")
    unlink("parts_1.out")
  } 
  
  ## gather information about MAP trees as a function of height
  if(file.exists(paste("./", "tree_m0_posts.out", sep=""))) {
    cat("INTERRUPT: removed tree_m0_posts.out\n")
    unlink("tree_m0_posts.out")
  }
 }

==> tgp_1.1-7.tar.gz: tgp/R/tgp.cleanup.R <==
#******************************************************************************* 
#
# Bayesian Regression and Adaptive Sampling with Gaussian Process Trees
# Copyright (C) 2005, University of California
# 
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# 
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
# 
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
#
# Questions? Contact Robert B. Gramacy (rbgramacy@ams.ucsc.edu)
#
#*******************************************************************************


"tgp.cleanup" <-
  function()
{
  .C("tgp_cleanup", PACKAGE = "tgp")
  
  if(file.exists(paste("./", "best_parts_1.out", sep=""))) {
    cat("INTERRUPT: removed best_parts_1.out\n")
    unlink("best_parts_1.out")
  } 
  
  if(file.exists(paste("./", "tree_m0_posts.out", sep=""))) {
    cat("INTERRUPT: removed tree_m0_posts.out\n")
    unlink("tree_m0_posts.out")
  }

  if(file.exists(paste("./", "trace_parts_1.out", sep=""))) {
    cat("INTERRUPT: removed trace_parts_1.out\n")
    unlink("trace_parts_1.out")
  } 

  if(file.exists(paste("./", "trace_post_1.out", sep=""))) {
    cat("INTERRUPT: removed trace_post_1.out\n")
    unlink("trace_post_1.out")
  } 

  if(file.exists(paste("./", "trace_linarea_1.out", sep=""))) {
    cat("INTERRUPT: removed trace_linarea_1.out\n")
    unlink("trace_linarea_1.out")
  } 

  if(file.exists(paste("./", "trace_XX_1.out", sep=""))) {
    cat("INTERRUPT: removed trace_XX_1.out\n")
    unlink("trace_XX_1.out")
  } 

  if(file.exists(paste("./", "trace_ZZ_1.out", sep=""))) {
    cat("INTERRUPT: removed trace_ZZ_1.out\n")
    unlink("trace_ZZ_1.out")
  } 
 }
